@@ -1,6 +1,6 @@
-package Dist::Zilla::Chrome::Test;
+package Dist::Zilla::Chrome::Test 6.008;
 # ABSTRACT: the chrome used by Dist::Zilla::Tester
-$Dist::Zilla::Chrome::Test::VERSION = '5.043';
+
 use Moose;
 
 use MooseX::Types::Moose qw(ArrayRef HashRef Str);
@@ -87,7 +87,7 @@ Dist::Zilla::Chrome::Test - the chrome used by Dist::Zilla::Tester
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 ATTRIBUTES
 
@@ -110,7 +110,7 @@ construction with the C<set_response_for> method:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
