@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::CPANFile;
+package Dist::Zilla::Plugin::CPANFile 6.008;
 # ABSTRACT: produce a cpanfile prereqs file
-$Dist::Zilla::Plugin::CPANFile::VERSION = '5.043';
+
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -88,7 +88,7 @@ Dist::Zilla::Plugin::CPANFile - produce a cpanfile prereqs file
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 DESCRIPTION
 
@@ -103,7 +103,7 @@ file.  It defaults, of course, to F<cpanfile>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
