@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::MetaConfig;
+package Dist::Zilla::Plugin::MetaConfig 6.008;
 # ABSTRACT: summarize Dist::Zilla configuration into distmeta
-$Dist::Zilla::Plugin::MetaConfig::VERSION = '5.043';
+
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
@@ -36,7 +36,7 @@ sub metadata {
   };
 
   $dump->{perl} = {
-    version => $],
+    version => "$]",
   };
 
   for my $plugin (@{ $self->zilla->plugins }) {
@@ -74,7 +74,7 @@ Dist::Zilla::Plugin::MetaConfig - summarize Dist::Zilla configuration into distm
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 DESCRIPTION
 
@@ -94,7 +94,7 @@ Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
