@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::NextRelease;
+package Dist::Zilla::Plugin::NextRelease 6.008;
 # ABSTRACT: update the next release number in your changelog
-$Dist::Zilla::Plugin::NextRelease::VERSION = '5.043';
+
 use namespace::autoclean;
 
 use Moose;
@@ -10,7 +10,7 @@ with (
   'Dist::Zilla::Role::AfterRelease',
 );
 
-use Path::Tiny;
+use Dist::Zilla::Path;
 use Moose::Util::TypeConstraints;
 use List::Util 'first';
 use String::Formatter 0.100680 stringf => {
@@ -32,10 +32,10 @@ use String::Formatter 0.100680 stringf => {
     E => sub { $_[0]->_user_info('email') },
     U => sub { $_[0]->_user_info('name')  },
     T => sub { $_[0]->zilla->is_trial
-                   ? (defined $_[1] ? $_[1] : '-TRIAL') : '' },
+                   ? ($_[1] // '-TRIAL') : '' },
     V => sub { $_[0]->zilla->version
                 . ($_[0]->zilla->is_trial
-                   ? (defined $_[1] ? $_[1] : '-TRIAL') : '') },
+                   ? ($_[1] // '-TRIAL') : '') },
     P => sub {
       my $releaser = first { $_->can('cpanid') } @{ $_[0]->zilla->plugins_with('-Releaser') };
       $_[0]->log_fatal('releaser doesn\'t provide cpanid, but %P used') unless $releaser;
@@ -113,7 +113,7 @@ sub munge_files {
   my ($self) = @_;
 
   my ($file) = grep { $_->name eq $self->filename } @{ $self->zilla->files };
-  return unless $file;
+  $self->log_fatal([ 'failed to find %s in the distribution', $self->filename ]) if not $file;
 
   # save original unmunged content, for replacing back in the repo later
   my $content = $self->_original_changes_content($file->content);
@@ -246,7 +246,7 @@ __PACKAGE__->meta->make_immutable;
 #pod The email address of the user making this release (from C<user_stash>).
 #pod
 #pod = C<%P>
-#pod The CPAN (PAUSE) id of the user namking this release (from -Releaser plugins;
+#pod The CPAN (PAUSE) id of the user making this release (from -Releaser plugins;
 #pod see L<[UploadToCPAN]|Dist::Zilla::Plugin::UploadToCPAN/username>).
 #pod
 #pod = C<%n>
@@ -281,7 +281,7 @@ Dist::Zilla::Plugin::NextRelease - update the next release number in your change
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 SYNOPSIS
 
@@ -382,7 +382,7 @@ The email address of the user making this release (from C<user_stash>).
 
 =item C<%P>
 
-The CPAN (PAUSE) id of the user namking this release (from -Releaser plugins;
+The CPAN (PAUSE) id of the user making this release (from -Releaser plugins;
 see L<[UploadToCPAN]|Dist::Zilla::Plugin::UploadToCPAN/username>).
 
 =item C<%n>
@@ -409,7 +409,7 @@ L<TextTemplate|Dist::Zilla::Role::TextTemplate>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
