@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::ShareDir;
+package Dist::Zilla::Plugin::ShareDir 6.008;
 # ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::VERSION = '5.043';
+
 use Moose;
 
 use namespace::autoclean;
@@ -56,7 +56,7 @@ Dist::Zilla::Plugin::ShareDir - install a directory's contents as "ShareDir" con
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 SYNOPSIS
 
@@ -69,7 +69,7 @@ If no C<dir> is provided, the default is F<share>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
