@@ -1,6 +1,6 @@
-package Dist::Zilla::PluginBundle::Filter;
+package Dist::Zilla::PluginBundle::Filter 6.008;
 # ABSTRACT: use another bundle, with some plugins removed
-$Dist::Zilla::PluginBundle::Filter::VERSION = '5.043';
+
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle';
 
@@ -84,9 +84,8 @@ sub bundle_config {
 
   return @plugins unless my $remove = $config->{filter}->{remove};
 
-  require List::MoreUtils;
   for my $i (reverse 0 .. $#plugins) {
-    splice @plugins, $i, 1 if List::MoreUtils::any(sub {
+    splice @plugins, $i, 1 if any(sub {
       $plugins[$i][1] eq Dist::Zilla::Util->expand_config_package_name($_)
     }, @$remove);
   }
@@ -109,7 +108,7 @@ Dist::Zilla::PluginBundle::Filter - use another bundle, with some plugins remove
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 SYNOPSIS
 
@@ -144,7 +143,7 @@ Dist::Zilla roles: L<PluginBundle|Dist::Zilla::Role::PluginBundle>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
