@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::AfterMint;
+package Dist::Zilla::Role::AfterMint 6.008;
 # ABSTRACT: something that runs after minting is mostly complete
-$Dist::Zilla::Role::AfterMint::VERSION = '5.043';
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -32,7 +32,7 @@ Dist::Zilla::Role::AfterMint - something that runs after minting is mostly compl
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 DESCRIPTION
 
@@ -44,7 +44,7 @@ data:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
