@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::Chrome;
+package Dist::Zilla::Role::Chrome 6.008;
 # ABSTRACT: something that provides a user interface for Dist::Zilla
-$Dist::Zilla::Role::Chrome::VERSION = '5.043';
+
 use Moose::Role;
 
 use namespace::autoclean;
@@ -25,11 +25,11 @@ Dist::Zilla::Role::Chrome - something that provides a user interface for Dist::Z
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
