@@ -1,12 +1,12 @@
-package Dist::Zilla::Role::MintingProfile;
+package Dist::Zilla::Role::MintingProfile 6.008;
 # ABSTRACT: something that can find a minting profile dir
-$Dist::Zilla::Role::MintingProfile::VERSION = '5.043';
+
 use Moose::Role;
 
 use namespace::autoclean;
 
+use Dist::Zilla::Path;
 use File::ShareDir;
-use Path::Class;
 
 #pod =head1 DESCRIPTION
 #pod
@@ -29,6 +29,11 @@ use Path::Class;
 
 requires 'profile_dir';
 
+around profile_dir => sub {
+  my ($orig, $self, @args) = @_;
+  path($self->$orig(@args));
+};
+
 1;
 
 __END__
@@ -43,7 +48,7 @@ Dist::Zilla::Role::MintingProfile - something that can find a minting profile di
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 DESCRIPTION
 
@@ -64,7 +69,7 @@ based on your profile with the:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
