@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::Releaser;
+package Dist::Zilla::Role::Releaser 6.008;
 # ABSTRACT: something that makes a release of the dist
-$Dist::Zilla::Role::Releaser::VERSION = '5.043';
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::Releaser - something that makes a release of the dist
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 DESCRIPTION
 
@@ -38,7 +38,7 @@ releasing.  It's passed the distribution tarball to be released.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
