@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::ShareDir;
+package Dist::Zilla::Role::ShareDir 6.008;
 # ABSTRACT: something that picks a directory to install as shared files
-$Dist::Zilla::Role::ShareDir::VERSION = '5.043';
+
 use Moose::Role;
 with 'Dist::Zilla::Role::FileFinder';
 
@@ -26,11 +26,11 @@ Dist::Zilla::Role::ShareDir - something that picks a directory to install as sha
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
