@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::StubBuild;
+package Dist::Zilla::Role::StubBuild 6.008;
 # ABSTRACT: provides an empty BUILD methods
-$Dist::Zilla::Role::StubBuild::VERSION = '5.043';
+
 use Moose::Role;
 
 sub BUILD {}
@@ -19,11 +19,11 @@ Dist::Zilla::Role::StubBuild - provides an empty BUILD methods
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
