@@ -1,6 +1,6 @@
-package Dist::Zilla::Stash::User;
+package Dist::Zilla::Stash::User 6.008;
 # ABSTRACT: a stash of user name and email
-$Dist::Zilla::Stash::User::VERSION = '5.043';
+
 use Moose;
 
 use namespace::autoclean;
@@ -38,11 +38,11 @@ Dist::Zilla::Stash::User - a stash of user name and email
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
