@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Util::AuthorDeps;
+package Dist::Zilla::Util::AuthorDeps 6.008;
 # ABSTRACT: Utils for listing your distribution's author dependencies
-$Dist::Zilla::Util::AuthorDeps::VERSION = '5.043';
+
 use Dist::Zilla::Util;
 use Path::Tiny;
-use List::MoreUtils ();
+use List::Util 1.45 ();
 
 
 sub format_author_deps {
@@ -72,14 +72,16 @@ sub extract_author_deps {
   my @packages;
   while (<$fh>) {
     chomp;
-    next unless /\A\s*;\s*authordep\s*(\S+)\s*(?:=\s*(.+))?\s*\z/;
-    my $ver = defined $2 ? $2 : "0";
+    next unless /\A\s*;\s*authordep\s*(\S+)\s*(?:=\s*([^;]+))?\s*/;
+    my $module = $1;
+    my $ver = $2 // "0";
+    $ver =~ s/\s+$//;
     # Any "; authordep " is inserted at the beginning of the list
     # in the file order so the user can control the order of at least a part of
     # the plugin list
-    push @packages, $1;
+    push @packages, $module;
     # And added to the requirements so we can use it later
-    $reqs->add_string_requirement($1 => $ver);
+    $reqs->add_string_requirement($module => $ver);
   }
 
   my $vermap = $reqs->as_string_hash;
@@ -94,25 +96,33 @@ sub extract_author_deps {
   # for the common case (no inc::, no '; authordep') as in previous dzil
   # releases.
   @packages = ((sort grep /^inc::/, @packages), (grep !/^inc::/, @packages));
+  @packages = List::Util::uniq(@packages);
+
+  if ($missing) {
+    require Module::Runtime;
+
+    @packages =
+      grep {
+        $_ eq 'perl'
+        ? ! ($vermap->{perl} && eval "use $vermap->{perl}; 1")
+        : do {
+            my $m = $_;
+            ! eval {
+              # This will die if module is missing
+              Module::Runtime::require_module($m);
+              my $v = $vermap->{$m};
+              # This will die if VERSION is too low
+              !$v || $m->VERSION($v);
+              # Success!
+              1
+            }
+          }
+      } @packages;
+  }
 
   # Now that we have a sorted list of packages, use that to build an array of
   # hashrefs for display.
-  require List::MoreUtils;
-  require Class::Load;
-
-  my @final =
-    map { { $_ => $vermap->{$_} } }
-    grep {
-      $missing
-        ? $_ eq 'perl'
-          ? ($vermap->{perl} ? !eval "use $vermap->{perl}; 1" : ())
-          : (! Class::Load::try_load_class($_, ($vermap->{$_} ? {-version => $vermap->{$_}} : ())))
-        : 1
-      }
-    List::MoreUtils::uniq
-    @packages;
-
-  return \@final;
+  [ map { { $_ => $vermap->{$_} } } @packages ]
 }
 
 1;
@@ -129,11 +139,11 @@ Dist::Zilla::Util::AuthorDeps - Utils for listing your distribution's author dep
 
 =head1 VERSION
 
-version 5.043
+version 6.008
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
